(* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Efficiency and accuracy paramter settings for the thermal averges, tabulations
and solution of Boltzmann equations (nBE, cBE and fBE)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% *)

(* path for storing the output *)
outpath = "<specify path>";

(* Boltzmann equations solved in temperature interval x=m/T in [xmin,xmax] *)
xmin             = 10;
xmax             = 10^(8);

(* *****************************************************  nBE and cBE ***************************************************** *)
(* nBE.wl *)
nBEerr           = 10^(-3);                (* Max relative error between Euler and Trapezoidal method *)
nBEsafety        = 0.9;                    (* Safety factor for adapting h *)
nBEhinit         = 10^(-4);                (* Initial value of step size h at xmin *)
(* cBE.wl *)
cBEerr           = 10^(-3);                (* Max relative error between Euler and Trapezoidal method *)
cBEsafety        = 0.9;                    (* Safety factor for adapting h *)
cBEhinit         = 10^(-4);                (* Initial value of step size h at xmin *)
cBEerrNewton     = 0.1*cBEerr;             (* Max relative error for Newton iteration root finding *)
cBEerrMaxNewton  = 0.4;                    (* Maximum allowed relative change of improved solution at each Newton interation step *)

(* rates.wl and thermalavg.wl *)
(* Tabulation and interpolation settings for <sv>, <sv>_2, \[Gamma] *)
Nx               = 50;                     (* # of initial points in tabulation*)
iacc             = 0.1;                    (* parameter governing relative accuracy demanded for adaptive procedure of tabulations *)
imax             = 5;                      (* max number of iterations of adaptive tabulation procedure *)
pg               = 5;                      (* PrecisionGoal for <sv> and <sv>_2 *)
RelThermalAv     = True;                   (* True: sv[s_] relativistic thermally averaged (default). False: sv[vrel_] non-rel. thermally averaged *)


(* *****************************************************  fBE  **************************************************** *)
(* fBE.wl *)
fBEerr           = 10^(-4);                (* Max relative error between Euler and Trapezoidal method *)
fBEsafety        = 0.9;                    (* Safety factor for adapting h *)
fBEhinit         = 10^(-4);                (* Initial value of step size h at xmin *)
fBEerrNewton     = 0.1*fBEerr;             (* Max relative error for Newton iteration root finding *)
fBEerrMaxNewton  = 0.2;                    (* Maximum allowed relative change of improved solution at each Newton interation step *)
(* momentum space discretization of phase space density f(x,q), where dimensionless q= p/Sqrt[m_chi T]*)
qmin             = 10^-8;                  (* min. value of q for phase-space density *)
qmax             = 12;                     (* max. value of q for phase-space density *)
qN               = 200;                    (* # of momentum bins regularily distributed between qmin and qmax. fBE runtime depends quadratically on this value*)
qATOqB           = 0.1;                    (* change momentum coordinates if Abs(yeq/y-1)>qATOqB*)
(* Settings for initializing fBE with nBE abundance *)
gamcap           = 10^5;                   (* initializes fBE with nBE abundance at gamma/H=gamcap *)
nBEprevious      = False;                  (* if nBE was executed with the same model parameters before fBE call, the previous nBE results are used if value is True *)

(* thermalavg.wl*)
(* Tabulation settings for <sv>_theta *)
plotMaxR         = 5;                      (* recursion limit in the tabulation of <sv>_theta *)
plotPoints       = 50;                     (* initial # of points *)
Np               = 200;                    (* density of the denser regular table *)


(* ***************************************************** other settings ***************************************************** *)
dof             = "dof_Drees_etal.dat";  (* degrees of freedom choice: "const" = constant or <filename> for tabulated: *)
Analyticsvtheta = False;                 (* True: fBE adopts annihilation matrix with analytic <sigmav>_theta as defined by user, see threshold example in WIMP_th.wl *)
FullCel         = False;                 (* If True, cBE and fBE adoptes full Cell with <W> as defined by user, see threshold example in WIMP_th.wl *)
KDonly          = False;                 (* True: annihilation switched off in cBE and fBE *)
